pm4py.algo.evaluation.simplicity.variants package
=================================================

Submodules
----------

pm4py.algo.evaluation.simplicity.variants.arc\_degree module
------------------------------------------------------------

.. automodule:: pm4py.algo.evaluation.simplicity.variants.arc_degree
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation.simplicity.variants
   :members:
   :undoc-members:
   :show-inheritance:
